/*---------------------------------------------------------------------------\
| Project:  PIC18F458 CAN Node Core Firmware
|
| File:     core.h
|
| Descr.:   Main include file for the whole shebang.
|           SHOULD NOT BE MODIFIED BY APPLICATIONS.
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _CORE_H // Don't include more than once (last line = #endif)
#define _CORE_H


//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------

// note that "bit" type is directly supported by PICC-18.

typedef unsigned char       uint8_t;
typedef signed char         int8_t;

typedef unsigned int        uint16_t;
typedef signed int          int16_t;

typedef unsigned long       uint32_t;
typedef signed long         int32_t;



//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------



#define CORE_VERSION 4


#define TRUE        1
#define FALSE       0

#define ENABLE      1
#define DISABLE     0

#define ENABLED     1
#define DISABLED    0

#define HIGHPRIORITY        1
#define LOWPRIORITY         0


//------------------------------------------------------------------------
// Global variable declarations used in all other modules (extern'ed)
//------------------------------------------------------------------------

// None

#endif              // _CORE_H


//------------------------------------------------------------------------
// Other includes necessary for most files.
//------------------------------------------------------------------------

// Core includes

#include <pic18.h>      // Include for PICC-18
#include "pic18fxx8.h"  // Register definitions for the PIC18F458
#include "error.h"      // Includes for error handling
#include "ports.h"      // Includes for the port peripherals
#include "timer2.h"     // Includes for the Timer2 peripheral
#include "serial.h"     // Includes for the serial peripheral (UART )
#include "can.h"        // Includes for the CAN peripheral
#include "ints.h"       // Includes for interrupts

// User definable includes

#include "..\config.h"   // Application specific settings for the core


