/*---------------------------------------------------------------------------\
| Project:  Generic LV2 PIC18F458 CAN node firmware
|
| File:     ports.h
|
| Descr.:   Includes for the ports.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _PORTS_H    // Don't include more than once (last line = #endif)
#define _PORTS_H

//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------


// None


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

#define PORTS_PORTB_PULLUP_MASK     0b00000001
#define PORTS_PORTB_PULLUPS_ON      0b00000001
#define PORTS_PORTB_PULLUPS_OFF     0b00000000

#define PORTS_INT0_EDGE_MASK        0b00000010
#define PORTS_INT0_RISING_EDGE      0b00000010
#define PORTS_INT0_FALLING_EDGE     0b00000000

#define PORTS_INT1_EDGE_MASK        0b00000010
#define PORTS_INT1_RISING_EDGE      0b00000100
#define PORTS_INT1_FALLING_EDGE     0b00000000

//------------------------------------------------------------------------
// #defined "inline functions" (PICC18 does not allow inline functions)
//------------------------------------------------------------------------

#define DisableInt0Ints()     INT0IE = 0
#define EnableInt0Ints()      INT0IE = 1

#define DisableInt1Ints()     INT1IE = 0
#define EnableInt1Ints()      INT1IE = 1

#define DisablePbiocInts()    RBIE = 0
#define EnablePbiocInts()     RBIE = 1

#define ClearInt0Interrupt()  INT0IF = 0
#define ClearInt1Interrupt()  INT1IF = 0
#define ClearPbiocInterrupt() RBIF = 0

//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------

void InitializePorts ( uint8_t latchA, uint8_t directionA,
                       uint8_t latchB, uint8_t directionB,
                       uint8_t latchC, uint8_t directionC,
                       uint8_t latchD, uint8_t directionD,
                       uint8_t latchE, uint8_t directionE,
                       uint8_t portOptionsMask);

// INT0 declarations (set in config.h)

#if INTS_INT0_ISR_USED == INTS_CORE_ISR_ENABLED
void Int0Isr (void);
#endif

#if INTS_INT0_APPLICATION_HOOK == INTS_HOOK_ENABLED
void Int0ApplicationHandler (void);
#endif

// INT1 declarations (set in config.h)

#if INTS_INT1_ISR_USED == INTS_CORE_ISR_ENABLED
void Int1Isr (void);
#endif

#if INTS_INT1_APPLICATION_HOOK == INTS_HOOK_ENABLED
void Int1ApplicationHandler (void);
#endif

// Port B Interrupt On Change (PBIOC) declarations (set in config.h)

#if INTS_PBIOC_ISR_USED == INTS_CORE_ISR_ENABLED
void PbiocIsr (void);
#endif

#if INTS_PBIOC_APPLICATION_HOOK == INTS_HOOK_ENABLED
void PbiocApplicationHandler (void);
#endif


//------------------------------------------------------------------------
// Module-wide variable declarations
//------------------------------------------------------------------------


// None


#endif              // _PORTS_H




