/*---------------------------------------------------------------------------\
| Project:  Generic LV2 PIC18F458 CAN node firmware
|
| File:     timer2.h
|
| Descr.:   Includes for the timer2.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _TIMER2_H   // Don't include more than once (last line = #endif)
#define _TIMER2_H

//------------------------------------------------------------------------
// Typedefs, enums, etc.
//------------------------------------------------------------------------

enum TIMER2_INIT_MASK
{
    TIMER2_ENABLE               = 0b10000000,
    TIMER2_DISABLE              = 0b00000000,
    TIMER2_ENABLE_INTS          = 0b01000000,
    TIMER2_DISABLE_INTS         = 0b00000000,

    TIMER2_250HZ                = 0b00000000,   // ** ASSUMES 20MHZ **
    TIMER2_500HZ                = 0b00000001,   // ** ASSUMES 20MHZ **
    TIMER2_1KHZ                 = 0b00000010,   // ** ASSUMES 20MHZ **
    TIMER2_2KHZ                 = 0b00000011,   // ** ASSUMES 20MHZ **
    TIMER2_2_5KHZ               = 0b00000100,   // ** ASSUMES 20MHZ **
    TIMER2_5KHZ                 = 0b00000101,   // ** ASSUMES 20MHZ **
};


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// Clear the Timer2 interrupt flag

#define ClearTimer2Interrupt()  TMR2IF = 0


// Enabled and disable Timer2 interrupts and set priorities

#define DisableTimer2Ints()     TMR2IE = 0
#define EnableTimer2Ints()      TMR2IE = 1

#define SetLPTimer2Ints()       TMR2IP = 0
#define SetHPTimer2Ints()       TMR2IP = 1



//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------


void InitializeTimer2 (enum TIMER2_INIT_MASK optionsMask);

#if INTS_TIMER2_ISR_USED == INTS_CORE_ISR_ENABLED
void Timer2Isr (void);
#endif

#if INTS_TIMER2_APPLICATION_HOOK == INTS_HOOK_ENABLED
void Timer2ApplicationHandler (void);
#endif



//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

// None

#endif              // _TIMER2_H





